@@ -11,8 +11,8 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 
-Version = '1.12'
-Build = '6'
+Version = '2.1'
+Build = '1'
 
 import sys
 import os
@@ -26,10 +26,11 @@ from PyQt4.QtMaemo5 import *
 
 from clevenMainUI import *
 from clevenDriversUI import *
-from clevenDecryptUI import *
+from clevenManageCapturedUI import *
 from clevenDictionaryUI import *
 from clevenKeysUI import *
 from clevenStartupUI import *
+from clevenCaptureUI import *
 
 pathMain             = '/opt/cleven'                        # main path of files
 pathTemp             = '/home/user/.cleven'                 # temp path of files
@@ -55,7 +56,7 @@ def showQuickMessage(message):
                /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
                string:"%s"' % message)          
 
-class clevenMainWindow(QtGui.QMainWindow): # need fixes
+class clevenMainWindow(QtGui.QMainWindow):
 
     def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, parent)
@@ -68,34 +69,16 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        ##Connect Menu Buttons 
        QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
        QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.showAboutWindow)
-       QtCore.QObject.connect(self.ui.actionConfigureDrivers, QtCore.SIGNAL('triggered()'), self.showConfigureDriversDialog)
-       QtCore.QObject.connect(self.ui.actionDecryptCaptured, QtCore.SIGNAL('triggered()'), self.showDecryptWindow)
-       QtCore.QObject.connect(self.ui.actionShowKeys, QtCore.SIGNAL('triggered()'), self.showKeysWindow)
        
-       ##Access Point
-       QtCore.QObject.connect(self.ui.scanButton, QtCore.SIGNAL('clicked()'), self.scanNetworks)
-       QtCore.QObject.connect(self.ui.wepRadio, QtCore.SIGNAL('clicked()'), self.displayNetworks)
-       QtCore.QObject.connect(self.ui.wpaRadio, QtCore.SIGNAL('clicked()'), self.displayNetworks)
-       QtCore.QObject.connect(self.ui.scanList, QtCore.SIGNAL('itemSelectionChanged()'), self.displayNetworkInformation)
-
-       ##Capture of packets
-       QtCore.QObject.connect(self.ui.captureButton, QtCore.SIGNAL('clicked()'), self.executeCapture)
-       QtCore.QObject.connect(self.ui.authenticateButton, QtCore.SIGNAL('clicked()'), self.executeAuthenticate)
-       QtCore.QObject.connect(self.ui.deauthenticateButton, QtCore.SIGNAL('clicked()'), self.executeDeauthenticate)
-       QtCore.QObject.connect(self.ui.injectionButton, QtCore.SIGNAL('clicked()'), self.executeInjection)
+       ##Connect Push Buttons
+       QtCore.QObject.connect(self.ui.pushButtonConfigureDrivers, QtCore.SIGNAL('clicked()'), self.showConfigureDriversDialog)
+       QtCore.QObject.connect(self.ui.pushButtonDecryptCaptured, QtCore.SIGNAL('clicked()'), self.showDecryptWindow)
+       QtCore.QObject.connect(self.ui.pushButtonShowKeys, QtCore.SIGNAL('clicked()'), self.showKeysWindow)
+       QtCore.QObject.connect(self.ui.pushButtonCapturePackets, QtCore.SIGNAL('clicked()'), self.showCaptureWindow)
+       QtCore.QObject.connect(self.ui.pushButtonDeleleCaptured, QtCore.SIGNAL('clicked()'), self.showDeleteWindow)
 
        self.showStartupDialog()          ## (Un)comment for pop-up of the start-up dialog at start-up
        # self.showConfigureDriversDialog() ## (Un)comment for pop-up of the configuration dialog at start-up  
-
-       self.ui.captureButton.setEnabled(False)
-       self.ui.injectionButton.setHidden(True)
-       self.ui.authenticateButton.setHidden(True)
-       self.ui.deauthenticateButton.setHidden(True)
-      
-       ##Show some info in the UI
-       self.ui.textBrowser.clear()
-       self.ui.textBrowser.append('Scan first for available networks')
-       self.ui.textBrowser.append('then choose WEP or WPA')
        
     def showAboutWindow(self):
        self.aboutWin = clevenAbout(self)
@@ -108,12 +91,56 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        DriverDialog = clevenConfigureDrivers()
        DriverDialog.exec_()
 
-    def showDecryptWindow(self):
-       self.aboutWin = clevenDecryptCaptured(self)
-
     def showKeysWindow(self):
        self.aboutWin = clevenShowKeys(self)
 
+    def showCaptureWindow(self):
+       self.aboutWin = clevenCapture(self)
+
+    def showDecryptWindow(self):
+       global deleteModeOn
+       deleteModeOn = 'False'
+       self.aboutWin =  clevenManageCaptured(self)       
+       
+    def showDeleteWindow(self):
+       global deleteModeOn
+       deleteModeOn = 'True'
+       self.aboutWin = clevenManageCaptured(self)
+       
+class clevenCapture(QtGui.QMainWindow):
+
+    def __init__(self, parent=None):
+    
+       ##Build the parent user interface
+       QtGui.QMainWindow.__init__(self, parent)
+       self.ui = Ui_clevenCaptureUI()
+       self.ui.setupUi(self)
+       self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+       self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+       self.show()       
+
+       ##Access Point
+       QtCore.QObject.connect(self.ui.scanButton, QtCore.SIGNAL('clicked()'), self.scanNetworks)
+       QtCore.QObject.connect(self.ui.wepRadio, QtCore.SIGNAL('clicked()'), self.displayNetworks)
+       QtCore.QObject.connect(self.ui.wpaRadio, QtCore.SIGNAL('clicked()'), self.displayNetworks)
+       QtCore.QObject.connect(self.ui.scanList, QtCore.SIGNAL('itemSelectionChanged()'), self.displayNetworkInformation)
+
+       ##Capture of packets
+       QtCore.QObject.connect(self.ui.captureButton, QtCore.SIGNAL('clicked()'), self.executeCapture)
+       QtCore.QObject.connect(self.ui.authenticateButton, QtCore.SIGNAL('clicked()'), self.executeAuthenticate)
+       QtCore.QObject.connect(self.ui.deauthenticateButton, QtCore.SIGNAL('clicked()'), self.executeDeauthenticate)
+       QtCore.QObject.connect(self.ui.injectionButton, QtCore.SIGNAL('clicked()'), self.executeInjection)
+
+       self.ui.captureButton.setEnabled(False)
+       self.ui.injectionButton.setHidden(True)
+       self.ui.authenticateButton.setHidden(True)
+       self.ui.deauthenticateButton.setHidden(True)
+      
+       ##Show some info in the UI
+       self.ui.textBrowser.clear()
+       self.ui.textBrowser.append('Scan first for available networks')
+       self.ui.textBrowser.append('then choose WEP or WPA')
+       
     def scanNetworks(self):
        '''Initiate scanning for available networks'''
        
@@ -259,7 +286,7 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        # print "injection options: ", bssid, myMAC
        os.system('osso-xterm -e "sudo %s/%s injection %s %s" &' % (pathMain, helperScript, bssid, myMAC))
        
-class clevenConfigureDrivers(QtGui.QDialog): # Complete
+class clevenConfigureDrivers(QtGui.QDialog):
 
     def __init__(self, parent=None):
        ##Build the parent user interface
@@ -448,7 +475,7 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        ##Set user requested value for the "Connect automatically" option 
        os.system('gconftool-2 -s --type list --list-type string /system/osso/connectivity/network_type/auto_connect [%s]' % String)
 
-class clevenSelectDictionary(QtGui.QDialog): # Complete
+class clevenSelectDictionary(QtGui.QDialog):
 
     def __init__(self, parent=None):
        ##Build the parent user interface
@@ -470,40 +497,33 @@ class clevenSelectDictionary(QtGui.QDialog): # Complete
 
        self.close()
 
-class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
+class clevenManageCaptured(QtGui.QMainWindow):
 
     def __init__(self, parent=None):
        ##Build the parent user interface
        QtGui.QMainWindow.__init__(self, parent)
-       self.ui = Ui_clevenDecryptUI()
+       self.ui = Ui_clevenManageCapturedUI()
        self.ui.setupUi(self)
        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
-
-       ##Connect Menu Buttons 
-       QtCore.QObject.connect(self.ui.actionEnableDeleteOptions, QtCore.SIGNAL('triggered()'), self.enableDeleteOptions)
-       QtCore.QObject.connect(self.ui.actionDisableDeleteOptions, QtCore.SIGNAL('triggered()'), self.disableDeleteOptions)
        
        ##Decryption and Deletion actions
-       QtCore.QObject.connect(self.ui.decryptButton, QtCore.SIGNAL('clicked()'), self.decryptORdeleteCapturedFiles)
+       QtCore.QObject.connect(self.ui.performActionButton, QtCore.SIGNAL('clicked()'), self.actOnCapturedFiles)
        QtCore.QObject.connect(self.ui.dictionaryButton, QtCore.SIGNAL('clicked()'), self.showSelectDictionaryDialog)
-       QtCore.QObject.connect(self.ui.capturedList, QtCore.SIGNAL('itemSelectionChanged()'), self.enableDecryptionButtons)
+       QtCore.QObject.connect(self.ui.capturedList, QtCore.SIGNAL('itemSelectionChanged()'), self.enableActionButtons)
        QtCore.QObject.connect(self.ui.wepRadio, QtCore.SIGNAL('clicked()'), self.showCapturedFiles)
        QtCore.QObject.connect(self.ui.wpaRadio, QtCore.SIGNAL('clicked()'), self.showCapturedFiles)
        
        self.show()       
 
-       self.ui.decryptButton.setEnabled(False)
+       self.ui.performActionButton.setEnabled(False)
        self.ui.selectCommonRadio.setEnabled(False)
-       self.ui.actionEnableDeleteOptions.setEnabled(True)
-       self.ui.actionDisableDeleteOptions.setEnabled(False)       
        self.ui.dictionaryLine.setEnabled(False)
        self.ui.dictionaryButton.setHidden(True)
        self.ui.dictionaryLine.setHidden(True)
        
-       global deleteModeOn
-       deleteModeOn = 'False'
-
+       self.enableOptions()
+       
     def showSelectDictionaryDialog(self):
        '''Open the dictionary selection dialog'''
        
@@ -511,43 +531,34 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        DictionariesDialog.exec_()
        self.ui.dictionaryLine.setText(myDictionary)
 
-    def enableDecryptionButtons(self):
+    def enableActionButtons(self):
        '''Enable in the UI the Decrypt button'''
       
-       self.ui.decryptButton.setEnabled(True)
+       self.ui.performActionButton.setEnabled(True)
        self.ui.selectCommonRadio.setEnabled(True)
 
-    def enableDeleteOptions(self):
-       '''Enable in the UI the Delete buttons'''
+    def enableOptions(self):
+       '''Prepare the UI to either have the Delete or Decrypt options'''
+     
+       if deleteModeOn == 'True':
        
-       global deleteModeOn
-       deleteModeOn = 'True'
+          self.setWindowTitle('Deletion')
+          
+          self.ui.performActionButton.setEnabled(False)
+          self.ui.performActionButton.setText('Delete')       
+          self.ui.selectCommonRadio.setEnabled(False)
+          
+          ##Hide the dictionary selection buttons 
+          self.ui.dictionaryButton.setHidden(True)
+          self.ui.dictionaryLine.setHidden(True)
+      
+       else:  
 
-       self.setWindowTitle('Deletion')
-       
-       self.ui.decryptButton.setEnabled(False)
-       self.ui.decryptButton.setText('Delete')       
-       self.ui.selectCommonRadio.setEnabled(False)
-       self.ui.actionEnableDeleteOptions.setEnabled(False)
-       self.ui.actionDisableDeleteOptions.setEnabled(True)
-       
-       ##Hide the dictionary selection buttons 
-       self.ui.dictionaryButton.setHidden(True)
-       self.ui.dictionaryLine.setHidden(True)
-
-       
-    def disableDeleteOptions(self):
-       '''Disable in the UI the Delete buttons'''
-
-       global deleteModeOn
-       deleteModeOn = 'False'
-       
-       self.ui.decryptButton.setEnabled(False)
-       self.ui.decryptButton.setText('Decrypt')
-       self.ui.selectCommonRadio.setEnabled(False)
-       self.ui.actionEnableDeleteOptions.setEnabled(True)
-       self.ui.actionDisableDeleteOptions.setEnabled(False)
-       self.setWindowTitle('Decryption')
+          self.setWindowTitle('Decryption')
+          
+          self.ui.performActionButton.setEnabled(False)
+          self.ui.performActionButton.setText('Decrypt')
+          self.ui.selectCommonRadio.setEnabled(False)
        
     def showCapturedFiles(self):
        '''Read and add in the UI the captured file list'''
@@ -564,18 +575,18 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
             self.ui.dictionaryLine.setHidden(False)
 
        self.ui.capturedList.clear() 
-       self.ui.decryptButton.setEnabled(False)
+       self.ui.performActionButton.setEnabled(False)
        
        clist = os.listdir(pathTemp + '/' + folderCapturedData + '/' + encryption)
        clist_clean = [line for line in clist if (('.cap' in line) or ('.ivs' in line))]
        clist_clean.sort(key=str.lower)
        self.ui.capturedList.addItems(clist_clean)
 
-    def decryptORdeleteCapturedFiles(self):
+    def actOnCapturedFiles(self):
        '''Start the decryption OR deletion of the captured files saved in the system'''
 
        if self.ui.capturedList.currentRow() == -1:
-          self.ui.decryptButton.setEnabled(False)
+          self.ui.performActionButton.setEnabled(False)
           return
           
        self.capfile = str(self.ui.capturedList.currentItem().text())
@@ -598,7 +609,7 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
           
           if self.ui.wpaRadio.isChecked():
              if myDictionary == '':
-                self.ui.decryptButton.setEnabled(False)
+                self.ui.performActionButton.setEnabled(False)
                 return
              else:
                 os.system('osso-xterm -e "sudo %s/%s decryptWPA %s %s %s %s" &' % (pathMain, helperScript, pathTemp, myDictionary, key, cap))
@@ -626,7 +637,7 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
           os.system('sudo %s/%s deleteCaptured %s %s %s' % (pathMain, helperScript, pathTemp, encryption, cap))
           self.showCapturedFiles()          
          
-class clevenShowKeys(QtGui.QMainWindow): # Complete
+class clevenShowKeys(QtGui.QMainWindow):
 
     def __init__(self, parent=None):
     
@@ -668,7 +679,7 @@ class clevenShowKeys(QtGui.QMainWindow): # Complete
        except IOError:
           self.ui.keyBrowser.setText("Key file cannot be read..")
 
-class clevenAbout(QtGui.QMainWindow): # Complete
+class clevenAbout(QtGui.QMainWindow):
     '''About Window'''
       
     def __init__(self, parent=None):
@@ -738,7 +749,7 @@ class clevenAbout(QtGui.QMainWindow): # Complete
     def openIssueTracker(self):
        QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/Cleven'))
 
-class clevenStartup(QtGui.QDialog): # Complete
+class clevenStartup(QtGui.QDialog):
     '''Application start up dialog'''
     
     def __init__(self, parent=None):
@@ -761,7 +772,7 @@ class clevenStartup(QtGui.QDialog): # Complete
        self.step = self.step + 2
        self.ui.progressBarStart.setValue(self.step)
     
-class clevenMain(): # Complete
+class clevenMain():
 
     ##Check with what priviledges the GUI has been executed.
     if os.geteuid() == 0:
